import java.lang
import java.math
import java.util
import org.ergoplatform
import org.ergoplatform.appkit
import org.ergoplatform.explorer.client
import org.ergoplatform.explorer.client.model
import org.ergoplatform.restapi.client
import org.ergoplatform.wallet.protocol.context
import scala
import scala.collection
import scala.collection.immutable
import sigmastate
import sigmastate.interpreter
import special.collection
import special.sigma
import typing



class BlockchainContextBase(org.ergoplatform.appkit.BlockchainContext):
    def __init__(self, networkType: org.ergoplatform.appkit.NetworkType): ...
    def compileContract(self, constants: org.ergoplatform.appkit.Constants, string: typing.Union[java.lang.String, str]) -> org.ergoplatform.appkit.ErgoContract: ...
    def getNetworkType(self) -> org.ergoplatform.appkit.NetworkType: ...
    def getParameters(self) -> org.ergoplatform.appkit.BlockchainParameters: ...
    def newContract(self, ergoTree: sigmastate.Values.ErgoTree) -> org.ergoplatform.appkit.ErgoContract: ...
    def parseReducedTransaction(self, byteArray: typing.List[int]) -> org.ergoplatform.appkit.ReducedTransaction: ...
    def parseSignedTransaction(self, byteArray: typing.List[int]) -> org.ergoplatform.appkit.SignedTransaction: ...

class BlockchainContextBuilderImpl(org.ergoplatform.appkit.BlockchainContextBuilder):
    def __init__(self, blockchainDataSource: org.ergoplatform.appkit.BlockchainDataSource, networkType: org.ergoplatform.appkit.NetworkType): ...
    def build(self) -> org.ergoplatform.appkit.BlockchainContext: ...

class BoxAttachmentBuilder:
    def __init__(self): ...
    @staticmethod
    def buildFromAdditionalRegisters(additionalRegisters: org.ergoplatform.explorer.client.model.AdditionalRegisters) -> org.ergoplatform.appkit.BoxAttachment: ...
    @staticmethod
    def buildFromHexEncodedErgoValue(string: typing.Union[java.lang.String, str]) -> org.ergoplatform.appkit.BoxAttachment: ...
    @staticmethod
    def buildFromTransactionBox(transactionBox: org.ergoplatform.appkit.TransactionBox) -> org.ergoplatform.appkit.BoxAttachment: ...
    @staticmethod
    def createMultiAttachment(list: java.util.List[org.ergoplatform.appkit.BoxAttachment]) -> org.ergoplatform.appkit.BoxAttachmentMulti: ...
    @staticmethod
    def createPlainTextAttachment(string: typing.Union[java.lang.String, str]) -> org.ergoplatform.appkit.BoxAttachmentPlainText: ...
    @staticmethod
    def getAttachmentRegisterIndex() -> int: ...

class Eip4TokenBuilder:
    def __init__(self): ...
    @staticmethod
    def buildFromAdditionalRegisters(string: typing.Union[java.lang.String, str], long: int, additionalRegisters: org.ergoplatform.explorer.client.model.AdditionalRegisters) -> org.ergoplatform.appkit.Eip4Token: ...
    @staticmethod
    def buildFromErgoBox(string: typing.Union[java.lang.String, str], transactionBox: org.ergoplatform.appkit.TransactionBox) -> org.ergoplatform.appkit.Eip4Token: ...
    @staticmethod
    def buildFromExplorerByIssuingBox(defaultApi: org.ergoplatform.explorer.client.DefaultApi, string: typing.Union[java.lang.String, str], string2: typing.Union[java.lang.String, str]) -> org.ergoplatform.appkit.Eip4Token: ...
    @staticmethod
    def buildFromExplorerByTokenId(defaultApi: org.ergoplatform.explorer.client.DefaultApi, string: typing.Union[java.lang.String, str]) -> org.ergoplatform.appkit.Eip4Token: ...
    @staticmethod
    def buildFromHexEncodedRegisters(string: typing.Union[java.lang.String, str], long: int, list: java.util.List[typing.Union[java.lang.String, str]]) -> org.ergoplatform.appkit.Eip4Token: ...
    @staticmethod
    def buildNftAudioToken(string: typing.Union[java.lang.String, str], long: int, string2: typing.Union[java.lang.String, str], string3: typing.Union[java.lang.String, str], int: int, byteArray: typing.List[int], string4: typing.Union[java.lang.String, str], string5: typing.Union[java.lang.String, str]) -> org.ergoplatform.appkit.Eip4Token: ...
    @staticmethod
    def buildNftPictureToken(string: typing.Union[java.lang.String, str], long: int, string2: typing.Union[java.lang.String, str], string3: typing.Union[java.lang.String, str], int: int, byteArray: typing.List[int], string4: typing.Union[java.lang.String, str]) -> org.ergoplatform.appkit.Eip4Token: ...
    @staticmethod
    def buildNftVideoToken(string: typing.Union[java.lang.String, str], long: int, string2: typing.Union[java.lang.String, str], string3: typing.Union[java.lang.String, str], int: int, byteArray: typing.List[int], string4: typing.Union[java.lang.String, str]) -> org.ergoplatform.appkit.Eip4Token: ...

class ErgoProverBuilderImpl(org.ergoplatform.appkit.ErgoProverBuilder):
    org$ergoplatform$appkit$impl$ErgoProverBuilderImpl$$_ctx: BlockchainContextBase = ...
    def __init__(self, _ctx: BlockchainContextBase): ...
    def build(self) -> org.ergoplatform.appkit.ErgoProver: ...
    def withDHTData(self, g: special.sigma.GroupElement, h: special.sigma.GroupElement, u: special.sigma.GroupElement, v: special.sigma.GroupElement, x: java.math.BigInteger) -> org.ergoplatform.appkit.ErgoProverBuilder: ...
    def withDLogSecret(self, x: java.math.BigInteger) -> org.ergoplatform.appkit.ErgoProverBuilder: ...
    def withEip3Secret(self, index: int) -> org.ergoplatform.appkit.ErgoProverBuilder: ...
    @typing.overload
    def withMnemonic(self, mnemonic: org.ergoplatform.appkit.Mnemonic) -> org.ergoplatform.appkit.ErgoProverBuilder: ...
    @typing.overload
    def withMnemonic(self, mnemonicPhrase: org.ergoplatform.appkit.SecretString, mnemonicPass: org.ergoplatform.appkit.SecretString) -> org.ergoplatform.appkit.ErgoProverBuilder: ...
    def withSecretStorage(self, storage: org.ergoplatform.appkit.SecretStorage) -> org.ergoplatform.appkit.ErgoProverBuilder: ...

class ErgoProverImpl(org.ergoplatform.appkit.ErgoProver):
    def __init__(self, _ctx: BlockchainContextBase, _prover: org.ergoplatform.appkit.AppkitProvingInterpreter): ...
    def getAddress(self) -> org.ergoplatform.appkit.Address: ...
    def getEip3Addresses(self) -> java.util.List[org.ergoplatform.appkit.Address]: ...
    def getP2PKAddress(self) -> org.ergoplatform.P2PKAddress: ...
    def getSecretKey(self) -> special.sigma.BigInt: ...
    def reduce(self, tx: org.ergoplatform.appkit.UnsignedTransaction, baseCost: int) -> org.ergoplatform.appkit.ReducedTransaction: ...
    @typing.overload
    def sign(self, tx: org.ergoplatform.appkit.UnsignedTransaction) -> org.ergoplatform.appkit.SignedTransaction: ...
    @typing.overload
    def sign(self, tx: org.ergoplatform.appkit.UnsignedTransaction, baseCost: int) -> org.ergoplatform.appkit.SignedTransaction: ...
    def signMessage(self, sigmaProp: org.ergoplatform.appkit.SigmaProp, message: typing.List[int], hintsBag: sigmastate.interpreter.HintsBag) -> typing.List[int]: ...
    def signReduced(self, tx: org.ergoplatform.appkit.ReducedTransaction, baseCost: int) -> org.ergoplatform.appkit.SignedTransaction: ...

class ErgoScriptContract(org.ergoplatform.appkit.ErgoContract):
    @staticmethod
    def create(constants: org.ergoplatform.appkit.Constants, string: typing.Union[java.lang.String, str], networkType: org.ergoplatform.appkit.NetworkType) -> 'ErgoScriptContract': ...
    def getConstants(self) -> org.ergoplatform.appkit.Constants: ...
    def getErgoScript(self) -> java.lang.String: ...
    def getErgoTree(self) -> sigmastate.Values.ErgoTree: ...
    def substConstant(self, string: typing.Union[java.lang.String, str], object: typing.Any) -> 'ErgoScriptContract': ...
    def toAddress(self) -> org.ergoplatform.appkit.Address: ...

class ErgoTreeContract(org.ergoplatform.appkit.ErgoContract):
    def __init__(self, ergoTree: sigmastate.Values.ErgoTree, networkType: org.ergoplatform.appkit.NetworkType): ...
    def getConstants(self) -> org.ergoplatform.appkit.Constants: ...
    def getErgoScript(self) -> java.lang.String: ...
    def getErgoTree(self) -> sigmastate.Values.ErgoTree: ...
    def substConstant(self, string: typing.Union[java.lang.String, str], object: typing.Any) -> 'ErgoTreeContract': ...
    def toAddress(self) -> org.ergoplatform.appkit.Address: ...

class InputBoxImpl(org.ergoplatform.appkit.InputBox):
    @typing.overload
    def __init__(self, ergoBox: org.ergoplatform.ErgoBox): ...
    @typing.overload
    def __init__(self, ergoTransactionOutput: org.ergoplatform.restapi.client.ErgoTransactionOutput): ...
    def getAttachment(self) -> org.ergoplatform.appkit.BoxAttachment: ...
    def getBytes(self) -> typing.List[int]: ...
    def getCreationHeight(self) -> int: ...
    def getErgoBox(self) -> org.ergoplatform.ErgoBox: ...
    def getErgoTree(self) -> sigmastate.Values.ErgoTree: ...
    def getExtension(self) -> sigmastate.interpreter.ContextExtension: ...
    def getId(self) -> org.ergoplatform.appkit.ErgoId: ...
    def getRegisters(self) -> java.util.List[org.ergoplatform.appkit.ErgoValue[typing.Any]]: ...
    def getTokens(self) -> java.util.List[org.ergoplatform.appkit.ErgoToken]: ...
    def getValue(self) -> int: ...
    @typing.overload
    def toJson(self, boolean: bool) -> java.lang.String: ...
    @typing.overload
    def toJson(self, boolean: bool, boolean2: bool) -> java.lang.String: ...
    def toString(self) -> java.lang.String: ...
    def withContextVars(self, *contextVar: org.ergoplatform.appkit.ContextVar) -> org.ergoplatform.appkit.InputBox: ...

class NodeAndExplorerDataSourceImpl(org.ergoplatform.appkit.BlockchainDataSource):
    performCheckBeforeSend: bool = ...
    def __init__(self, apiClient: org.ergoplatform.restapi.client.ApiClient, explorerApiClient: org.ergoplatform.explorer.client.ExplorerApiClient): ...
    def getBoxById(self, string: typing.Union[java.lang.String, str]) -> org.ergoplatform.appkit.InputBox: ...
    def getBoxByIdWithMemPool(self, string: typing.Union[java.lang.String, str]) -> org.ergoplatform.appkit.InputBox: ...
    def getExplorerApi(self) -> org.ergoplatform.explorer.client.DefaultApi: ...
    def getLastBlockHeaders(self, int: int, boolean: bool) -> java.util.List[org.ergoplatform.appkit.BlockHeader]: ...
    def getNodeBlocksApi(self) -> org.ergoplatform.restapi.client.BlocksApi: ...
    def getNodeInfoApi(self) -> org.ergoplatform.restapi.client.InfoApi: ...
    def getNodeTransactionsApi(self) -> org.ergoplatform.restapi.client.TransactionsApi: ...
    def getNodeUtxoApi(self) -> org.ergoplatform.restapi.client.UtxoApi: ...
    def getNodeWalletApi(self) -> org.ergoplatform.restapi.client.WalletApi: ...
    def getParameters(self) -> org.ergoplatform.appkit.BlockchainParameters: ...
    def getUnconfirmedTransactions(self, int: int, int2: int) -> java.util.List[org.ergoplatform.appkit.Transaction]: ...
    def getUnconfirmedUnspentBoxesFor(self, address: org.ergoplatform.appkit.Address, int: int, int2: int) -> java.util.List[org.ergoplatform.appkit.InputBox]: ...
    def getUnspentBoxesFor(self, address: org.ergoplatform.appkit.Address, int: int, int2: int) -> java.util.List[org.ergoplatform.appkit.InputBox]: ...
    def sendTransaction(self, signedTransaction: org.ergoplatform.appkit.SignedTransaction) -> java.lang.String: ...

class NodeInfoParameters(org.ergoplatform.appkit.BlockchainParameters):
    def __init__(self, nodeInfo: org.ergoplatform.restapi.client.NodeInfo): ...
    def getBlockVersion(self) -> int: ...
    def getDataInputCost(self) -> int: ...
    def getInputCost(self) -> int: ...
    def getMaxBlockCost(self) -> int: ...
    def getMaxBlockSize(self) -> int: ...
    def getMinValuePerByte(self) -> int: ...
    def getNetworkType(self) -> org.ergoplatform.appkit.NetworkType: ...
    def getOutputCost(self) -> int: ...
    def getStorageFeeFactor(self) -> int: ...
    def getTokenAccessCost(self) -> int: ...

class OutBoxBuilderImpl(org.ergoplatform.appkit.OutBoxBuilder):
    def __init__(self, _txB: 'UnsignedTransactionBuilderImpl'): ...
    def build(self) -> org.ergoplatform.appkit.OutBox: ...
    def contract(self, contract: org.ergoplatform.appkit.ErgoContract) -> 'OutBoxBuilderImpl': ...
    def creationHeight(self, height: int) -> org.ergoplatform.appkit.OutBoxBuilder: ...
    def mintToken(self, token: org.ergoplatform.appkit.Eip4Token) -> org.ergoplatform.appkit.OutBoxBuilder: ...
    @typing.overload
    def registers(self, registers: typing.List[org.ergoplatform.appkit.ErgoValue[typing.Any]]) -> 'OutBoxBuilderImpl': ...
    @typing.overload
    def registers(self, registers: scala.collection.Seq[org.ergoplatform.appkit.ErgoValue[typing.Any]]) -> 'OutBoxBuilderImpl': ...
    @typing.overload
    def tokens(self, tokens: typing.List[org.ergoplatform.appkit.ErgoToken]) -> 'OutBoxBuilderImpl': ...
    @typing.overload
    def tokens(self, tokens: scala.collection.Seq[org.ergoplatform.appkit.ErgoToken]) -> 'OutBoxBuilderImpl': ...
    def value(self, value: int) -> 'OutBoxBuilderImpl': ...

class OutBoxImpl(org.ergoplatform.appkit.OutBox):
    def __init__(self, _ergoBoxCandidate: org.ergoplatform.ErgoBoxCandidate): ...
    def convertToInputWith(self, txId: typing.Union[java.lang.String, str], boxIndex: int) -> org.ergoplatform.appkit.InputBox: ...
    def getAttachment(self) -> org.ergoplatform.appkit.BoxAttachment: ...
    def getBytesWithNoRef(self) -> typing.List[int]: ...
    def getCreationHeight(self) -> int: ...
    def getErgoBoxCandidate(self) -> org.ergoplatform.ErgoBoxCandidate: ...
    def getErgoTree(self) -> sigmastate.Values.ErgoTree: ...
    def getRegisters(self) -> java.util.List[org.ergoplatform.appkit.ErgoValue[typing.Any]]: ...
    def getTokens(self) -> java.util.List[org.ergoplatform.appkit.ErgoToken]: ...
    def getValue(self) -> int: ...

class PreHeaderBuilderImpl(org.ergoplatform.appkit.PreHeaderBuilder):
    def __init__(self, blockchainContextImpl: 'BlockchainContextImpl'): ...
    def build(self) -> org.ergoplatform.appkit.PreHeader: ...
    def height(self, integer: int) -> org.ergoplatform.appkit.PreHeaderBuilder: ...
    def minerPk(self, groupElement: special.sigma.GroupElement) -> org.ergoplatform.appkit.PreHeaderBuilder: ...
    def nBits(self, long: int) -> org.ergoplatform.appkit.PreHeaderBuilder: ...
    def parentId(self, coll: special.collection.Coll[int]) -> org.ergoplatform.appkit.PreHeaderBuilder: ...
    def timestamp(self, long: int) -> org.ergoplatform.appkit.PreHeaderBuilder: ...
    def version(self, byte: int) -> org.ergoplatform.appkit.PreHeaderBuilder: ...
    def votes(self, coll: special.collection.Coll[int]) -> org.ergoplatform.appkit.PreHeaderBuilder: ...

class PreHeaderImpl(org.ergoplatform.appkit.PreHeader):
    def __init__(self, preHeader: special.sigma.PreHeader): ...
    def getHeight(self) -> int: ...
    def getMinerPk(self) -> special.sigma.GroupElement: ...
    def getNBits(self) -> int: ...
    def getParentId(self) -> special.collection.Coll[int]: ...
    def getTimestamp(self) -> int: ...
    def getVersion(self) -> int: ...
    def getVotes(self) -> special.collection.Coll[int]: ...

class ReducedTransactionImpl(org.ergoplatform.appkit.ReducedTransaction):
    def __init__(self, blockchainContextBase: BlockchainContextBase, reducedErgoLikeTransaction: org.ergoplatform.appkit.ReducedErgoLikeTransaction, int: int): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getCost(self) -> int: ...
    def getId(self) -> java.lang.String: ...
    def getInputBoxesIds(self) -> java.util.List[java.lang.String]: ...
    def getOutputs(self) -> java.util.List[org.ergoplatform.appkit.OutBox]: ...
    def getTx(self) -> org.ergoplatform.appkit.ReducedErgoLikeTransaction: ...
    def hashCode(self) -> int: ...
    def toBytes(self) -> typing.List[int]: ...

class ScalaBridge:
    @staticmethod
    def isoAssetToErgoToken() -> org.ergoplatform.appkit.Iso[org.ergoplatform.restapi.client.Asset, org.ergoplatform.appkit.ErgoToken]: ...
    @staticmethod
    def isoAssetToPair() -> org.ergoplatform.appkit.Iso[org.ergoplatform.restapi.client.Asset, scala.Tuple2[typing.List[int], typing.Any]]: ...
    @staticmethod
    def isoBlockHeader() -> org.ergoplatform.appkit.Iso[org.ergoplatform.restapi.client.BlockHeader, special.sigma.Header]: ...
    @staticmethod
    def isoErgoTransaction() -> org.ergoplatform.appkit.Iso[org.ergoplatform.restapi.client.ErgoTransaction, org.ergoplatform.ErgoLikeTransaction]: ...
    @staticmethod
    def isoErgoTransactionDataInput() -> org.ergoplatform.appkit.Iso[org.ergoplatform.restapi.client.ErgoTransactionDataInput, org.ergoplatform.DataInput]: ...
    @staticmethod
    def isoErgoTransactionInput() -> org.ergoplatform.appkit.Iso[org.ergoplatform.restapi.client.ErgoTransactionInput, org.ergoplatform.Input]: ...
    @staticmethod
    def isoErgoTransactionOutput() -> org.ergoplatform.appkit.Iso[org.ergoplatform.restapi.client.ErgoTransactionOutput, org.ergoplatform.ErgoBox]: ...
    @staticmethod
    def isoExplRegistersToMap() -> org.ergoplatform.appkit.Iso[org.ergoplatform.explorer.client.model.AdditionalRegisters, scala.collection.immutable.Map[org.ergoplatform.ErgoBox.NonMandatoryRegisterId, sigmastate.Values.EvaluatedValue[sigmastate.SType]]]: ...
    @staticmethod
    def isoExplorerAssetToPair() -> org.ergoplatform.appkit.Iso[org.ergoplatform.explorer.client.model.AssetInfo, scala.Tuple2[typing.List[int], typing.Any]]: ...
    @staticmethod
    def isoRegistersToMap() -> org.ergoplatform.appkit.Iso[org.ergoplatform.restapi.client.Registers, scala.collection.immutable.Map[org.ergoplatform.ErgoBox.NonMandatoryRegisterId, sigmastate.Values.EvaluatedValue[sigmastate.SType]]]: ...
    @staticmethod
    def isoSpendingProof() -> org.ergoplatform.appkit.Iso[org.ergoplatform.restapi.client.SpendingProof, sigmastate.interpreter.ProverResult]: ...
    @staticmethod
    def isoStringToErgoTree() -> org.ergoplatform.appkit.Iso[java.lang.String, sigmastate.Values.ErgoTree]: ...
    @staticmethod
    def toSigmaHeader(h: org.ergoplatform.appkit.BlockHeader) -> special.sigma.Header: ...

class SignedInputImpl(org.ergoplatform.appkit.SignedInput):
    def __init__(self, signedTransactionImpl: 'SignedTransactionImpl', input: org.ergoplatform.Input): ...
    def getContextVars(self) -> java.util.Map[int, org.ergoplatform.appkit.ErgoValue[typing.Any]]: ...
    def getId(self) -> org.ergoplatform.appkit.ErgoId: ...
    def getProofBytes(self) -> typing.List[int]: ...
    def getTransaction(self) -> org.ergoplatform.appkit.SignedTransaction: ...

class SignedTransactionImpl(org.ergoplatform.appkit.SignedTransaction):
    def __init__(self, blockchainContextBase: BlockchainContextBase, ergoLikeTransaction: org.ergoplatform.ErgoLikeTransaction, int: int): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getCost(self) -> int: ...
    def getId(self) -> java.lang.String: ...
    def getInputBoxesIds(self) -> java.util.List[java.lang.String]: ...
    def getOutputs(self) -> java.util.List[org.ergoplatform.appkit.OutBox]: ...
    def getOutputsToSpend(self) -> java.util.List[org.ergoplatform.appkit.InputBox]: ...
    def getSignedInputs(self) -> java.util.List[org.ergoplatform.appkit.SignedInput]: ...
    def getTx(self) -> org.ergoplatform.ErgoLikeTransaction: ...
    def hashCode(self) -> int: ...
    def toBytes(self) -> typing.List[int]: ...
    @typing.overload
    def toJson(self, boolean: bool) -> java.lang.String: ...
    @typing.overload
    def toJson(self, boolean: bool, boolean2: bool) -> java.lang.String: ...
    def toString(self) -> java.lang.String: ...

class UnsignedTransactionBuilderImpl(org.ergoplatform.appkit.UnsignedTransactionBuilder):
    def __init__(self, _ctx: 'BlockchainContextImpl'): ...
    def _ctx(self) -> 'BlockchainContextImpl': ...
    def _dataInputs(self) -> java.util.List[org.ergoplatform.DataInput]: ...
    def _dataInputs_$eq(self, x$1: java.util.List[org.ergoplatform.DataInput]) -> None: ...
    def _inputs(self) -> java.util.List[org.ergoplatform.UnsignedInput]: ...
    def _inputs_$eq(self, x$1: java.util.List[org.ergoplatform.UnsignedInput]) -> None: ...
    def _outputCandidates(self) -> scala.Option[java.util.List[org.ergoplatform.ErgoBoxCandidate]]: ...
    def _outputCandidates_$eq(self, x$1: scala.Option[java.util.List[org.ergoplatform.ErgoBoxCandidate]]) -> None: ...
    def boxesToSpend(self, inputBoxes: java.util.List[org.ergoplatform.appkit.InputBox]) -> org.ergoplatform.appkit.UnsignedTransactionBuilder: ...
    def build(self) -> org.ergoplatform.appkit.UnsignedTransaction: ...
    def fee(self, feeAmount: int) -> org.ergoplatform.appkit.UnsignedTransactionBuilder: ...
    def getCtx(self) -> org.ergoplatform.appkit.BlockchainContext: ...
    _getDefined__T = typing.TypeVar('_getDefined__T')  # <T>
    def getDefined(self, opt: scala.Option[_getDefined__T], msg: scala.Function0[typing.Union[java.lang.String, str]]) -> _getDefined__T: ...
    def getInputBoxes(self) -> java.util.List[org.ergoplatform.appkit.InputBox]: ...
    def getNetworkType(self) -> org.ergoplatform.appkit.NetworkType: ...
    _getNonEmpty__T = typing.TypeVar('_getNonEmpty__T')  # <T>
    def getNonEmpty(self, list: scala.Option[java.util.List[_getNonEmpty__T]], msg: scala.Function0[typing.Union[java.lang.String, str]]) -> java.util.List[_getNonEmpty__T]: ...
    def getPreHeader(self) -> org.ergoplatform.appkit.PreHeader: ...
    def org$ergoplatform$appkit$impl$UnsignedTransactionBuilderImpl$$_ph(self) -> scala.Option[PreHeaderImpl]: ...
    def outBoxBuilder(self) -> OutBoxBuilderImpl: ...
    @typing.overload
    def outputs(self, outputs: typing.List[org.ergoplatform.appkit.OutBox]) -> org.ergoplatform.appkit.UnsignedTransactionBuilder: ...
    @typing.overload
    def outputs(self, outputs: scala.collection.Seq[org.ergoplatform.appkit.OutBox]) -> org.ergoplatform.appkit.UnsignedTransactionBuilder: ...
    def preHeader(self, ph: org.ergoplatform.appkit.PreHeader) -> org.ergoplatform.appkit.UnsignedTransactionBuilder: ...
    def sendChangeTo(self, changeAddress: org.ergoplatform.ErgoAddress) -> org.ergoplatform.appkit.UnsignedTransactionBuilder: ...
    @typing.overload
    def tokensToBurn(self, tokens: typing.List[org.ergoplatform.appkit.ErgoToken]) -> org.ergoplatform.appkit.UnsignedTransactionBuilder: ...
    @typing.overload
    def tokensToBurn(self, tokens: scala.collection.Seq[org.ergoplatform.appkit.ErgoToken]) -> org.ergoplatform.appkit.UnsignedTransactionBuilder: ...
    def withDataInputs(self, inputBoxes: java.util.List[org.ergoplatform.appkit.InputBox]) -> org.ergoplatform.appkit.UnsignedTransactionBuilder: ...

class UnsignedTransactionImpl(org.ergoplatform.appkit.UnsignedTransaction):
    def __init__(self, unsignedErgoLikeTransaction: org.ergoplatform.UnsignedErgoLikeTransaction, list: java.util.List[org.ergoplatform.appkit.ExtendedInputBox], list2: java.util.List[org.ergoplatform.ErgoBox], ergoAddress: org.ergoplatform.ErgoAddress, ergoLikeStateContext: org.ergoplatform.wallet.protocol.context.ErgoLikeStateContext, blockchainContextImpl: 'BlockchainContextImpl'): ...
    def getBoxesToSpend(self) -> java.util.List[org.ergoplatform.appkit.ExtendedInputBox]: ...
    def getChangeAddress(self) -> org.ergoplatform.ErgoAddress: ...
    def getDataBoxes(self) -> java.util.List[org.ergoplatform.ErgoBox]: ...
    def getDataInputs(self) -> java.util.List[org.ergoplatform.appkit.InputBox]: ...
    def getId(self) -> java.lang.String: ...
    def getInputBoxesIds(self) -> java.util.List[java.lang.String]: ...
    def getInputs(self) -> java.util.List[org.ergoplatform.appkit.InputBox]: ...
    def getOutputs(self) -> java.util.List[org.ergoplatform.appkit.OutBox]: ...
    def getStateContext(self) -> org.ergoplatform.wallet.protocol.context.ErgoLikeStateContext: ...
    def getTx(self) -> org.ergoplatform.UnsignedErgoLikeTransaction: ...

class BlockHeaderImpl(PreHeaderImpl, org.ergoplatform.appkit.BlockHeader):
    def __init__(self, header: special.sigma.Header, blockHeader: org.ergoplatform.restapi.client.BlockHeader): ...
    @staticmethod
    def createFromRestApi(blockHeader: org.ergoplatform.restapi.client.BlockHeader) -> 'BlockHeaderImpl': ...
    def getAdProofsRoot(self) -> special.collection.Coll[int]: ...
    def getExtensionHash(self) -> special.collection.Coll[int]: ...
    def getId(self) -> java.lang.String: ...
    def getPowSolutionsD(self) -> java.math.BigInteger: ...
    def getPowSolutionsN(self) -> special.collection.Coll[int]: ...
    def getPowSolutionsPk(self) -> special.sigma.GroupElement: ...
    def getPowSolutionsW(self) -> special.sigma.GroupElement: ...
    def getStateRoot(self) -> special.sigma.AvlTree: ...
    def getTransactionsRoot(self) -> special.collection.Coll[int]: ...

class BlockchainContextImpl(BlockchainContextBase):
    def __init__(self, blockchainDataSource: org.ergoplatform.appkit.BlockchainDataSource, networkType: org.ergoplatform.appkit.NetworkType): ...
    def createPreHeader(self) -> org.ergoplatform.appkit.PreHeaderBuilder: ...
    def getBoxesById(self, *string: typing.Union[java.lang.String, str]) -> typing.List[org.ergoplatform.appkit.InputBox]: ...
    def getCoveringBoxesFor(self, address: org.ergoplatform.appkit.Address, long: int, list: java.util.List[org.ergoplatform.appkit.ErgoToken]) -> org.ergoplatform.appkit.CoveringBoxes: ...
    def getDataSource(self) -> org.ergoplatform.appkit.BlockchainDataSource: ...
    def getHeaders(self) -> java.util.List[org.ergoplatform.appkit.BlockHeader]: ...
    def getHeight(self) -> int: ...
    def getParameters(self) -> org.ergoplatform.appkit.BlockchainParameters: ...
    def getUnspentBoxesFor(self, address: org.ergoplatform.appkit.Address, int: int, int2: int) -> java.util.List[org.ergoplatform.appkit.InputBox]: ...
    def newProverBuilder(self) -> org.ergoplatform.appkit.ErgoProverBuilder: ...
    def newTxBuilder(self) -> org.ergoplatform.appkit.UnsignedTransactionBuilder: ...
    def sendTransaction(self, signedTransaction: org.ergoplatform.appkit.SignedTransaction) -> java.lang.String: ...
    def signedTxFromJson(self, string: typing.Union[java.lang.String, str]) -> org.ergoplatform.appkit.SignedTransaction: ...

class ColdBlockchainContext(BlockchainContextBase):
    def __init__(self, networkType: org.ergoplatform.appkit.NetworkType, params: org.ergoplatform.appkit.BlockchainParameters): ...
    def createPreHeader(self) -> org.ergoplatform.appkit.PreHeaderBuilder: ...
    @typing.overload
    def getBoxesById(self, boxIds: typing.List[java.lang.String]) -> typing.List[org.ergoplatform.appkit.InputBox]: ...
    @typing.overload
    def getBoxesById(self, boxIds: scala.collection.Seq[typing.Union[java.lang.String, str]]) -> typing.List[org.ergoplatform.appkit.InputBox]: ...
    def getCoveringBoxesFor(self, address: org.ergoplatform.appkit.Address, amountToSpend: int, tokensToSpend: java.util.List[org.ergoplatform.appkit.ErgoToken]) -> org.ergoplatform.appkit.CoveringBoxes: ...
    def getDataSource(self) -> org.ergoplatform.appkit.BlockchainDataSource: ...
    def getHeight(self) -> int: ...
    def getParameters(self) -> org.ergoplatform.appkit.BlockchainParameters: ...
    def getUnspentBoxesFor(self, address: org.ergoplatform.appkit.Address, offset: int, limit: int) -> java.util.List[org.ergoplatform.appkit.InputBox]: ...
    def newProverBuilder(self) -> org.ergoplatform.appkit.ErgoProverBuilder: ...
    def newTxBuilder(self) -> org.ergoplatform.appkit.UnsignedTransactionBuilder: ...
    def sendTransaction(self, tx: org.ergoplatform.appkit.SignedTransaction) -> java.lang.String: ...
    def signedTxFromJson(self, json: typing.Union[java.lang.String, str]) -> org.ergoplatform.appkit.SignedTransaction: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.appkit.impl")``.

    BlockHeaderImpl: typing.Type[BlockHeaderImpl]
    BlockchainContextBase: typing.Type[BlockchainContextBase]
    BlockchainContextBuilderImpl: typing.Type[BlockchainContextBuilderImpl]
    BlockchainContextImpl: typing.Type[BlockchainContextImpl]
    BoxAttachmentBuilder: typing.Type[BoxAttachmentBuilder]
    ColdBlockchainContext: typing.Type[ColdBlockchainContext]
    Eip4TokenBuilder: typing.Type[Eip4TokenBuilder]
    ErgoProverBuilderImpl: typing.Type[ErgoProverBuilderImpl]
    ErgoProverImpl: typing.Type[ErgoProverImpl]
    ErgoScriptContract: typing.Type[ErgoScriptContract]
    ErgoTreeContract: typing.Type[ErgoTreeContract]
    InputBoxImpl: typing.Type[InputBoxImpl]
    NodeAndExplorerDataSourceImpl: typing.Type[NodeAndExplorerDataSourceImpl]
    NodeInfoParameters: typing.Type[NodeInfoParameters]
    OutBoxBuilderImpl: typing.Type[OutBoxBuilderImpl]
    OutBoxImpl: typing.Type[OutBoxImpl]
    PreHeaderBuilderImpl: typing.Type[PreHeaderBuilderImpl]
    PreHeaderImpl: typing.Type[PreHeaderImpl]
    ReducedTransactionImpl: typing.Type[ReducedTransactionImpl]
    ScalaBridge: typing.Type[ScalaBridge]
    SignedInputImpl: typing.Type[SignedInputImpl]
    SignedTransactionImpl: typing.Type[SignedTransactionImpl]
    UnsignedTransactionBuilderImpl: typing.Type[UnsignedTransactionBuilderImpl]
    UnsignedTransactionImpl: typing.Type[UnsignedTransactionImpl]



import java.lang
import org
import org.ergoplatform
import scala
import scala.collection
import scala.collection.immutable
import scala.collection.mutable
import scala.runtime
import scala.util
import scorex.util.serialization
import typing



_BoxSelector__BoxSelectionResult__T = typing.TypeVar('_BoxSelector__BoxSelectionResult__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
class BoxSelector:
    @staticmethod
    def $init$($this: 'BoxSelector') -> None: ...
    @staticmethod
    def MinBoxValue() -> int: ...
    @staticmethod
    def ScanDepthFactor() -> int: ...
    _select_0__T = typing.TypeVar('_select_0__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
    _select_1__T = typing.TypeVar('_select_1__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
    @typing.overload
    def select(self, inputBoxes: scala.collection.Iterator[_select_0__T], filterFn: scala.Function1[_select_0__T, typing.Any], targetBalance: int, targetAssets: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> scala.util.Either['BoxSelector.BoxSelectionError', 'BoxSelector.BoxSelectionResult'[_select_0__T]]: ...
    @typing.overload
    def select(self, inputBoxes: scala.collection.Iterator[_select_1__T], targetBalance: int, targetAssets: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> scala.util.Either['BoxSelector.BoxSelectionError', 'BoxSelector.BoxSelectionResult'[_select_1__T]]: ...
    class BoxSelectionError:
        def message(self) -> java.lang.String: ...
    class BoxSelectionResult(scala.Product, scala.Serializable, typing.Generic[_BoxSelector__BoxSelectionResult__T]):
        def __init__(self, boxes: scala.collection.Seq[_BoxSelector__BoxSelectionResult__T], changeBoxes: scala.collection.Seq[org.ergoplatform.ErgoBoxAssets]): ...
        def boxes(self) -> scala.collection.Seq[_BoxSelector__BoxSelectionResult__T]: ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        def changeBoxes(self) -> scala.collection.Seq[org.ergoplatform.ErgoBoxAssets]: ...
        _copy__T = typing.TypeVar('_copy__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
        def copy(self, boxes: scala.collection.Seq[org.ergoplatform.ErgoBoxAssets], changeBoxes: scala.collection.Seq[org.ergoplatform.ErgoBoxAssets]) -> 'BoxSelector.BoxSelectionResult'[org.ergoplatform.ErgoBoxAssets]: ...
        _copy$default$1__T = typing.TypeVar('_copy$default$1__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
        def copy$default$1(self) -> scala.collection.Seq[org.ergoplatform.ErgoBoxAssets]: ...
        _copy$default$2__T = typing.TypeVar('_copy$default$2__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
        def copy$default$2(self) -> scala.collection.Seq[org.ergoplatform.ErgoBoxAssets]: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> java.lang.String: ...
        def toString(self) -> java.lang.String: ...
    class BoxSelectionResult$(scala.Serializable):
        MODULE$: typing.ClassVar['BoxSelector.BoxSelectionResult.'] = ...
        def __init__(self): ...
        _apply__T = typing.TypeVar('_apply__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
        def apply(self, boxes: scala.collection.Seq[_apply__T], changeBoxes: scala.collection.Seq[org.ergoplatform.ErgoBoxAssets]) -> 'BoxSelector.BoxSelectionResult'[_apply__T]: ...
        def toString(self) -> java.lang.String: ...
        _unapply__T = typing.TypeVar('_unapply__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
        def unapply(self, x$0: 'BoxSelector.BoxSelectionResult'[_unapply__T]) -> scala.Option[scala.Tuple2[scala.collection.Seq[_unapply__T], scala.collection.Seq[org.ergoplatform.ErgoBoxAssets]]]: ...

class ErgoBoxAssetExtractor:
    @staticmethod
    def MaxAssetsPerBox() -> int: ...
    @staticmethod
    def extractAssets(boxes: scala.collection.IndexedSeq[org.ergoplatform.ErgoBoxCandidate]) -> scala.util.Try[scala.Tuple2[scala.collection.immutable.Map[scala.collection.Seq[typing.Any], typing.Any], typing.Any]]: ...
    @staticmethod
    def extractTotalAssetsAccessCost(inputBoxes: scala.collection.IndexedSeq[org.ergoplatform.ErgoBoxCandidate], outputBoxes: scala.collection.IndexedSeq[org.ergoplatform.ErgoBoxCandidate], tokenAccessCost: int) -> scala.util.Try[typing.Any]: ...
    @staticmethod
    def totalAssetsAccessCost(inAssetsNum: int, inAssetsSize: int, outAssetsNum: int, outAssetsSize: int, tokenAccessCost: int) -> int: ...

class ErgoBoxSerializer:
    @staticmethod
    def parse(r: scorex.util.serialization.Reader) -> org.ergoplatform.ErgoBox: ...
    @staticmethod
    def parseBytes(bytes: typing.List[int]) -> typing.Any: ...
    @staticmethod
    def parseBytesTry(bytes: typing.List[int]) -> scala.util.Try[org.ergoplatform.ErgoBox]: ...
    @staticmethod
    def parseTry(r: scorex.util.serialization.Reader) -> scala.util.Try[org.ergoplatform.ErgoBox]: ...
    @staticmethod
    def serialize(box: org.ergoplatform.ErgoBox, w: scorex.util.serialization.Writer) -> None: ...
    @staticmethod
    def toBytes(obj: typing.Any) -> typing.List[int]: ...

class TrackedBox(org.ergoplatform.ErgoBoxAssets, scala.Product, scala.Serializable):
    def __init__(self, creationTxId: typing.Union[java.lang.String, str], creationOutIndex: int, inclusionHeightOpt: scala.Option[typing.Any], spendingTxIdOpt: scala.Option[typing.Union[java.lang.String, str]], spendingHeightOpt: scala.Option[typing.Any], box: org.ergoplatform.ErgoBox, scans: scala.collection.immutable.Set[typing.Any]): ...
    @typing.overload
    @staticmethod
    def apply(creationTxId: typing.Union[java.lang.String, str], creationOutIndex: int, inclusionHeightOpt: scala.Option[typing.Any], spendingTxIdOpt: scala.Option[typing.Union[java.lang.String, str]], spendingHeightOpt: scala.Option[typing.Any], box: org.ergoplatform.ErgoBox, scans: scala.collection.immutable.Set[typing.Any]) -> 'TrackedBox': ...
    @typing.overload
    @staticmethod
    def apply(box: org.ergoplatform.ErgoBox, inclusionHeight: int, scans: scala.collection.immutable.Set[typing.Any]) -> 'TrackedBox': ...
    @typing.overload
    @staticmethod
    def apply(creationTx: org.ergoplatform.ErgoLikeTransaction, creationOutIndex: int, creationHeight: scala.Option[typing.Any], box: org.ergoplatform.ErgoBox, appStatuses: scala.collection.immutable.Set[typing.Any]) -> 'TrackedBox': ...
    def box(self) -> org.ergoplatform.ErgoBox: ...
    def boxId(self) -> java.lang.String: ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def chainStatus(self) -> 'ChainStatus': ...
    def copy(self, creationTxId: typing.Union[java.lang.String, str], creationOutIndex: int, inclusionHeightOpt: scala.Option[typing.Any], spendingTxIdOpt: scala.Option[typing.Union[java.lang.String, str]], spendingHeightOpt: scala.Option[typing.Any], box: org.ergoplatform.ErgoBox, scans: scala.collection.immutable.Set[typing.Any]) -> 'TrackedBox': ...
    def copy$default$1(self) -> java.lang.String: ...
    def copy$default$2(self) -> int: ...
    def copy$default$3(self) -> scala.Option[typing.Any]: ...
    def copy$default$4(self) -> scala.Option[java.lang.String]: ...
    def copy$default$5(self) -> scala.Option[typing.Any]: ...
    def copy$default$6(self) -> org.ergoplatform.ErgoBox: ...
    def copy$default$7(self) -> scala.collection.immutable.Set[typing.Any]: ...
    def creationChainStatus(self) -> 'ChainStatus': ...
    def creationOutIndex(self) -> int: ...
    def creationTxId(self) -> java.lang.String: ...
    def equals(self, obj: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def inclusionHeightOpt(self) -> scala.Option[typing.Any]: ...
    def isSpent(self) -> bool: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def scans(self) -> scala.collection.immutable.Set[typing.Any]: ...
    def spendingChainStatus(self) -> 'ChainStatus': ...
    def spendingHeightOpt(self) -> scala.Option[typing.Any]: ...
    def spendingStatus(self) -> 'SpendingStatus': ...
    def spendingTxIdOpt(self) -> scala.Option[java.lang.String]: ...
    def toString(self) -> java.lang.String: ...
    def tokens(self) -> scala.collection.immutable.Map[java.lang.String, typing.Any]: ...
    @staticmethod
    def unapply(x$0: 'TrackedBox') -> scala.Option[scala.Tuple7[java.lang.String, typing.Any, scala.Option[typing.Any], scala.Option[java.lang.String], scala.Option[typing.Any], org.ergoplatform.ErgoBox, scala.collection.immutable.Set[typing.Any]]]: ...
    def value(self) -> int: ...

class TrackedBoxSerializer:
    @staticmethod
    def parse(r: scorex.util.serialization.Reader) -> TrackedBox: ...
    @staticmethod
    def parseBytes(bytes: typing.List[int]) -> typing.Any: ...
    @staticmethod
    def parseBytesTry(bytes: typing.List[int]) -> scala.util.Try[TrackedBox]: ...
    @staticmethod
    def parseTry(r: scorex.util.serialization.Reader) -> scala.util.Try[TrackedBox]: ...
    @staticmethod
    def serialize(obj: TrackedBox, w: scorex.util.serialization.Writer) -> None: ...
    @staticmethod
    def toBytes(obj: typing.Any) -> typing.List[int]: ...

class DefaultBoxSelector:
    @staticmethod
    def formChangeBoxes(foundBalance: int, targetBalance: int, foundBoxAssets: scala.collection.mutable.Map[typing.Union[java.lang.String, str], typing.Any], targetBoxAssets: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> scala.util.Either[BoxSelector.BoxSelectionError, scala.collection.Seq[org.ergoplatform.ErgoBoxAssets]]: ...
    _select_0__T = typing.TypeVar('_select_0__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
    _select_1__T = typing.TypeVar('_select_1__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
    @typing.overload
    @staticmethod
    def select(inputBoxes: scala.collection.Iterator[_select_0__T], targetBalance: int, targetAssets: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> scala.util.Either[BoxSelector.BoxSelectionError, BoxSelector.BoxSelectionResult[_select_0__T]]: ...
    @typing.overload
    @staticmethod
    def select(inputBoxes: scala.collection.Iterator[_select_1__T], externalFilter: scala.Function1[_select_1__T, typing.Any], targetBalance: int, targetAssets: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> scala.util.Either[BoxSelector.BoxSelectionError, BoxSelector.BoxSelectionResult[_select_1__T]]: ...
    class NotEnoughCoinsForChangeBoxesError(BoxSelector.BoxSelectionError, scala.Product, scala.Serializable):
        def __init__(self, message: typing.Union[java.lang.String, str]): ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        def copy(self, message: typing.Union[java.lang.String, str]) -> 'DefaultBoxSelector.NotEnoughCoinsForChangeBoxesError': ...
        def copy$default$1(self) -> java.lang.String: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def message(self) -> java.lang.String: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> java.lang.String: ...
        def toString(self) -> java.lang.String: ...
    class NotEnoughCoinsForChangeBoxesError$(scala.runtime.AbstractFunction1[java.lang.String, 'DefaultBoxSelector.NotEnoughCoinsForChangeBoxesError'], scala.Serializable):
        MODULE$: typing.ClassVar['DefaultBoxSelector.NotEnoughCoinsForChangeBoxesError.'] = ...
        def __init__(self): ...
        def apply(self, message: typing.Union[java.lang.String, str]) -> 'DefaultBoxSelector.NotEnoughCoinsForChangeBoxesError': ...
        def toString(self) -> java.lang.String: ...
        def unapply(self, x$0: 'DefaultBoxSelector.NotEnoughCoinsForChangeBoxesError') -> scala.Option[java.lang.String]: ...
    class NotEnoughErgsError(BoxSelector.BoxSelectionError, scala.Product, scala.Serializable):
        def __init__(self, message: typing.Union[java.lang.String, str], balanceFound: int): ...
        def balanceFound(self) -> int: ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        def copy(self, message: typing.Union[java.lang.String, str], balanceFound: int) -> 'DefaultBoxSelector.NotEnoughErgsError': ...
        def copy$default$1(self) -> java.lang.String: ...
        def copy$default$2(self) -> int: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def message(self) -> java.lang.String: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> java.lang.String: ...
        def toString(self) -> java.lang.String: ...
    class NotEnoughErgsError$(scala.runtime.AbstractFunction2[java.lang.String, typing.Any, 'DefaultBoxSelector.NotEnoughErgsError'], scala.Serializable):
        MODULE$: typing.ClassVar['DefaultBoxSelector.NotEnoughErgsError.'] = ...
        def __init__(self): ...
        def apply(self, message: typing.Union[java.lang.String, str], balanceFound: int) -> 'DefaultBoxSelector.NotEnoughErgsError': ...
        def toString(self) -> java.lang.String: ...
        def unapply(self, x$0: 'DefaultBoxSelector.NotEnoughErgsError') -> scala.Option[scala.Tuple2[java.lang.String, typing.Any]]: ...
    class NotEnoughTokensError(BoxSelector.BoxSelectionError, scala.Product, scala.Serializable):
        def __init__(self, message: typing.Union[java.lang.String, str], tokensFound: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]): ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        def copy(self, message: typing.Union[java.lang.String, str], tokensFound: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> 'DefaultBoxSelector.NotEnoughTokensError': ...
        def copy$default$1(self) -> java.lang.String: ...
        def copy$default$2(self) -> scala.collection.immutable.Map[java.lang.String, typing.Any]: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def message(self) -> java.lang.String: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> java.lang.String: ...
        def toString(self) -> java.lang.String: ...
        def tokensFound(self) -> scala.collection.immutable.Map[java.lang.String, typing.Any]: ...
    class NotEnoughTokensError$(scala.runtime.AbstractFunction2[java.lang.String, scala.collection.immutable.Map[java.lang.String, typing.Any], 'DefaultBoxSelector.NotEnoughTokensError'], scala.Serializable):
        MODULE$: typing.ClassVar['DefaultBoxSelector.NotEnoughTokensError.'] = ...
        def __init__(self): ...
        def apply(self, message: typing.Union[java.lang.String, str], tokensFound: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> 'DefaultBoxSelector.NotEnoughTokensError': ...
        def toString(self) -> java.lang.String: ...
        def unapply(self, x$0: 'DefaultBoxSelector.NotEnoughTokensError') -> scala.Option[scala.Tuple2[java.lang.String, scala.collection.immutable.Map[java.lang.String, typing.Any]]]: ...

class ReplaceCompactCollectBoxSelector(BoxSelector):
    def __init__(self, maxInputs: int, optimalInputs: int): ...
    _calcChange__T = typing.TypeVar('_calcChange__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
    def calcChange(self, boxes: scala.collection.Seq[_calcChange__T], targetBalance: int, targetAssets: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> scala.util.Either[BoxSelector.BoxSelectionError, scala.collection.Seq[org.ergoplatform.ErgoBoxAssets]]: ...
    _collectDust__T = typing.TypeVar('_collectDust__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
    def collectDust(self, bsr: BoxSelector.BoxSelectionResult[_collectDust__T], tail: scala.collection.Seq[_collectDust__T], targetBalance: int, targetAssets: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> scala.util.Either[BoxSelector.BoxSelectionError, BoxSelector.BoxSelectionResult[_collectDust__T]]: ...
    _compress__T = typing.TypeVar('_compress__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
    def compress(self, bsr: BoxSelector.BoxSelectionResult[_compress__T], targetBalance: int, targetAssets: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> scala.util.Either[BoxSelector.BoxSelectionError, BoxSelector.BoxSelectionResult[_compress__T]]: ...
    _replace__T = typing.TypeVar('_replace__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
    def replace(self, bsr: BoxSelector.BoxSelectionResult[_replace__T], tail: scala.collection.Seq[_replace__T], targetBalance: int, targetAssets: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> scala.util.Either[BoxSelector.BoxSelectionError, BoxSelector.BoxSelectionResult[_replace__T]]: ...
    _select_0__T = typing.TypeVar('_select_0__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
    _select_1__T = typing.TypeVar('_select_1__T', bound=org.ergoplatform.ErgoBoxAssets)  # <T>
    @typing.overload
    def select(self, inputBoxes: scala.collection.Iterator[_select_0__T], targetBalance: int, targetAssets: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> scala.util.Either[BoxSelector.BoxSelectionError, BoxSelector.BoxSelectionResult[_select_0__T]]: ...
    @typing.overload
    def select(self, inputBoxes: scala.collection.Iterator[_select_1__T], filterFn: scala.Function1[_select_1__T, typing.Any], targetBalance: int, targetAssets: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any]) -> scala.util.Either[BoxSelector.BoxSelectionError, BoxSelector.BoxSelectionResult[_select_1__T]]: ...
    class MaxInputsExceededError(BoxSelector.BoxSelectionError, scala.Product, scala.Serializable):
        def __init__(self, message: typing.Union[java.lang.String, str]): ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        def copy(self, message: typing.Union[java.lang.String, str]) -> 'ReplaceCompactCollectBoxSelector.MaxInputsExceededError': ...
        def copy$default$1(self) -> java.lang.String: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def message(self) -> java.lang.String: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> java.lang.String: ...
        def toString(self) -> java.lang.String: ...
    class MaxInputsExceededError$(scala.runtime.AbstractFunction1[java.lang.String, 'ReplaceCompactCollectBoxSelector.MaxInputsExceededError'], scala.Serializable):
        MODULE$: typing.ClassVar['ReplaceCompactCollectBoxSelector.MaxInputsExceededError.'] = ...
        def __init__(self): ...
        def apply(self, message: typing.Union[java.lang.String, str]) -> 'ReplaceCompactCollectBoxSelector.MaxInputsExceededError': ...
        def toString(self) -> java.lang.String: ...
        def unapply(self, x$0: 'ReplaceCompactCollectBoxSelector.MaxInputsExceededError') -> scala.Option[java.lang.String]: ...

class ChainStatus:
    def __init__(self, onChain: bool): ...
    def onChain(self) -> bool: ...
    class OffChain$(org.ergoplatform.wallet.boxes.ChainStatus, scala.Product, scala.Serializable):
        MODULE$: typing.ClassVar['ChainStatus.OffChain.'] = ...
        def __init__(self): ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> java.lang.String: ...
        def toString(self) -> java.lang.String: ...
    class OnChain$(org.ergoplatform.wallet.boxes.ChainStatus, scala.Product, scala.Serializable):
        MODULE$: typing.ClassVar['ChainStatus.OnChain.'] = ...
        def __init__(self): ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> java.lang.String: ...
        def toString(self) -> java.lang.String: ...

class SpendingStatus:
    def __init__(self, spent: bool): ...
    def spent(self) -> bool: ...
    class Spent$(org.ergoplatform.wallet.boxes.SpendingStatus, scala.Product, scala.Serializable):
        MODULE$: typing.ClassVar['SpendingStatus.Spent.'] = ...
        def __init__(self): ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> java.lang.String: ...
        def toString(self) -> java.lang.String: ...
    class Unspent$(org.ergoplatform.wallet.boxes.SpendingStatus, scala.Product, scala.Serializable):
        MODULE$: typing.ClassVar['SpendingStatus.Unspent.'] = ...
        def __init__(self): ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> java.lang.String: ...
        def toString(self) -> java.lang.String: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.wallet.boxes")``.

    BoxSelector: typing.Type[BoxSelector]
    ChainStatus: typing.Type[ChainStatus]
    DefaultBoxSelector: typing.Type[DefaultBoxSelector]
    ErgoBoxAssetExtractor: typing.Type[ErgoBoxAssetExtractor]
    ErgoBoxSerializer: typing.Type[ErgoBoxSerializer]
    ReplaceCompactCollectBoxSelector: typing.Type[ReplaceCompactCollectBoxSelector]
    SpendingStatus: typing.Type[SpendingStatus]
    TrackedBox: typing.Type[TrackedBox]
    TrackedBoxSerializer: typing.Type[TrackedBoxSerializer]



import java.lang
import org
import org.ergoplatform
import scala
import scala.collection
import scala.collection.immutable
import scala.runtime
import scala.util
import scalan
import scorex.crypto.authds.avltree.batch
import scorex.crypto.hash
import sigmastate
import sigmastate.eval
import sigmastate.interpreter
import special.collection
import special.sigma
import typing



class AvlTreeHelpers:
    @staticmethod
    def createAvlTree(flags: sigmastate.AvlTreeFlags, entries: scala.collection.Seq[scala.Tuple2[typing.List[int], typing.List[int]]]) -> scala.Tuple2[special.sigma.AvlTree, scorex.crypto.authds.avltree.batch.BatchAVLProver[typing.List[int], scorex.crypto.hash.Blake2b256.]]: ...
    class ADKeyArrayOps:
        def __init__(self, arr: typing.List[typing.List[int]]): ...
        def toColl(self) -> special.collection.Coll[special.collection.Coll[typing.Any]]: ...
    class ADKeyValueArrayOps:
        def __init__(self, arr: typing.List[scala.Tuple2[typing.List[int], typing.List[int]]]): ...
        def toColl(self) -> special.collection.Coll[scala.Tuple2[special.collection.Coll[typing.Any], special.collection.Coll[typing.Any]]]: ...

class ContractSyntax:
    @staticmethod
    def $init$($this: 'ContractSyntax') -> None: ...
    _Coll__T = typing.TypeVar('_Coll__T')  # <T>
    def Coll(self, items: scala.collection.Seq[_Coll__T], cT: scalan.RType[_Coll__T]) -> special.collection.Coll[_Coll__T]: ...
    def Env(self, entries: scala.collection.Seq[scala.Tuple2[typing.Union[java.lang.String, str], typing.Any]]) -> scala.collection.immutable.Map[java.lang.String, typing.Any]: ...
    def builder(self) -> special.sigma.SigmaDslBuilder: ...
    def contractEnv(self) -> scala.collection.immutable.Map[java.lang.String, typing.Any]: ...
    def org$ergoplatform$dsl$ContractSyntax$_setter_$syntax_$eq(self, x$1: special.sigma.DslSyntaxExtensions) -> None: ...
    def proposition(self, name: typing.Union[java.lang.String, str], dslSpec: scala.Function1[special.sigma.Context, special.sigma.SigmaProp], scriptCode: typing.Union[java.lang.String, str], scriptVersion: scala.Option[typing.Any]) -> 'ContractSpec.PropositionSpec': ...
    def proposition$default$4(self) -> scala.Option[typing.Any]: ...
    def spec(self) -> 'ContractSpec': ...
    def syntax(self) -> special.sigma.DslSyntaxExtensions: ...
    def verifier(self) -> 'ContractSpec.VerifyingParty': ...
    class ErgoScript(scala.Product, scala.Serializable):
        def __init__(self, env: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any], code: typing.Union[java.lang.String, str], scriptVersion: scala.Option[typing.Any]): ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        def code(self) -> java.lang.String: ...
        def copy(self, env: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any], code: typing.Union[java.lang.String, str], scriptVersion: scala.Option[typing.Any]) -> 'ContractSyntax.ErgoScript': ...
        def copy$default$1(self) -> scala.collection.immutable.Map[java.lang.String, typing.Any]: ...
        def copy$default$2(self) -> java.lang.String: ...
        def copy$default$3(self) -> scala.Option[typing.Any]: ...
        def env(self) -> scala.collection.immutable.Map[java.lang.String, typing.Any]: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> java.lang.String: ...
        def scriptVersion(self) -> scala.Option[typing.Any]: ...
        def toString(self) -> java.lang.String: ...
    class ErgoScript$(scala.runtime.AbstractFunction3[scala.collection.immutable.Map[java.lang.String, typing.Any], java.lang.String, scala.Option[typing.Any], 'ContractSyntax.ErgoScript'], scala.Serializable):
        MODULE$: typing.ClassVar['ContractSyntax.ErgoScript.'] = ...
        def __init__(self): ...
        def apply(self, env: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any], code: typing.Union[java.lang.String, str], scriptVersion: scala.Option[typing.Any]) -> 'ContractSyntax.ErgoScript': ...
        def toString(self) -> java.lang.String: ...
        def unapply(self, x$0: 'ContractSyntax.ErgoScript') -> scala.Option[scala.Tuple3[scala.collection.immutable.Map[java.lang.String, typing.Any], java.lang.String, scala.Option[typing.Any]]]: ...
    class Token(scala.Product, scala.Serializable):
        def __init__(self, id: special.collection.Coll[typing.Any], value: int): ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        def copy(self, id: special.collection.Coll[typing.Any], value: int) -> 'ContractSyntax.Token': ...
        def copy$default$1(self) -> special.collection.Coll[typing.Any]: ...
        def copy$default$2(self) -> int: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def id(self) -> special.collection.Coll[typing.Any]: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> java.lang.String: ...
        def toString(self) -> java.lang.String: ...
        def value(self) -> int: ...
    class Token$(scala.runtime.AbstractFunction2[special.collection.Coll[typing.Any], typing.Any, 'ContractSyntax.Token'], scala.Serializable):
        MODULE$: typing.ClassVar['ContractSyntax.Token.'] = ...
        def __init__(self): ...
        def apply(self, id: special.collection.Coll[typing.Any], value: int) -> 'ContractSyntax.Token': ...
        def toString(self) -> java.lang.String: ...
        def unapply(self, x$0: 'ContractSyntax.Token') -> scala.Option[scala.Tuple2[special.collection.Coll[typing.Any], typing.Any]]: ...

class StdContracts:
    @staticmethod
    def $init$($this: 'StdContracts') -> None: ...
    def transferErgWithChange(self, tx: 'ContractSpec.TransactionCandidate', from_: 'ContractSpec.OutBox', to: 'ContractSpec.PropositionSpec', ergAmt: int) -> scala.Tuple2['ContractSpec.OutBox', scala.Option['ContractSpec.OutBox']]: ...
    def transferTokenWithChange(self, tx: 'ContractSpec.TransactionCandidate', from_: 'ContractSpec.OutBox', to: 'ContractSpec.PropositionSpec', tokenAmt: ContractSyntax.Token) -> scala.Tuple2['ContractSpec.OutBox', scala.Option['ContractSpec.OutBox']]: ...

class SigmaContractSyntax(special.sigma.SigmaContract, ContractSyntax): ...

class ContractSpec:
    @staticmethod
    def $init$($this: 'ContractSpec') -> None: ...
    _Coll__T = typing.TypeVar('_Coll__T')  # <T>
    def Coll(self, items: typing.Any, cT: scalan.RType[_Coll__T]) -> special.collection.Coll[_Coll__T]: ...
    def Colls(self) -> special.collection.CollBuilder: ...
    def IR(self) -> sigmastate.eval.IRContext: ...
    def MinErgValue(self) -> int: ...
    def dsl(self) -> special.sigma.SigmaDslBuilder: ...
    def error(self, msg: typing.Union[java.lang.String, str]) -> scala.runtime.Nothing.: ...
    def mkPropositionSpec(self, name: typing.Union[java.lang.String, str], dslSpec: scala.Function1[special.sigma.Context, special.sigma.SigmaProp], scriptSpec: ContractSyntax.ErgoScript) -> 'ContractSpec.PropositionSpec': ...
    def mkProvingParty(self, name: typing.Union[java.lang.String, str]) -> 'ContractSpec.ProvingParty': ...
    def mkVerifyingParty(self, name: typing.Union[java.lang.String, str]) -> 'ContractSpec.VerifyingParty': ...
    def org$ergoplatform$dsl$ContractSpec$_setter_$Colls_$eq(self, x$1: special.collection.CollBuilder) -> None: ...
    def org$ergoplatform$dsl$ContractSpec$_setter_$MinErgValue_$eq(self, x$1: int) -> None: ...
    def org$ergoplatform$dsl$ContractSpec$_setter_$dsl_$eq(self, x$1: special.sigma.SigmaDslBuilder) -> None: ...
    class BlockCandidate:
        def height(self) -> int: ...
        def newTransaction(self) -> 'ContractSpec.TransactionCandidate': ...
    class ChainBlock:
        def getTransactions(self) -> scala.collection.Seq['ContractSpec.ChainTransaction']: ...
    class ChainTransaction:
        def outputs(self) -> scala.collection.Seq['ContractSpec.OutBox']: ...
    class InputBox:
        def runDsl(self, extensions: scala.collection.immutable.Map[typing.Any, special.sigma.AnyValue]) -> special.sigma.SigmaProp: ...
        def runDsl$default$1(self) -> scala.collection.immutable.Map[typing.Any, special.sigma.AnyValue]: ...
        def toErgoContext(self) -> org.ergoplatform.ErgoLikeContext: ...
        def tx(self) -> 'ContractSpec.TransactionCandidate': ...
        def utxoBox(self) -> 'ContractSpec.OutBox': ...
    class OutBox:
        def boxIndex(self) -> int: ...
        def ergoBox(self) -> org.ergoplatform.ErgoBox: ...
        def id(self) -> typing.List[int]: ...
        def propSpec(self) -> 'ContractSpec.PropositionSpec': ...
        def token(self, id: special.collection.Coll[typing.Any]) -> ContractSyntax.Token: ...
        def tx(self) -> 'ContractSpec.TransactionCandidate': ...
        def value(self) -> int: ...
        def withRegs(self, regs: scala.collection.Seq[scala.Tuple2[org.ergoplatform.ErgoBox.NonMandatoryRegisterId, typing.Any]]) -> 'ContractSpec.OutBox': ...
        def withTokens(self, tokens: scala.collection.Seq[ContractSyntax.Token]) -> 'ContractSpec.OutBox': ...
    class PropositionSpec:
        def dslSpec(self) -> scala.Function1[special.sigma.Context, special.sigma.SigmaProp]: ...
        def ergoTree(self) -> sigmastate.Values.ErgoTree: ...
        def name(self) -> java.lang.String: ...
        def scriptSpec(self) -> ContractSyntax.ErgoScript: ...
    class PropositionSpec$:
        def __init__(self, $outer: 'ContractSpec'): ...
        def apply(self, name: typing.Union[java.lang.String, str], dslSpec: scala.Function1[special.sigma.Context, special.sigma.SigmaProp], scriptSpec: ContractSyntax.ErgoScript) -> 'ContractSpec.PropositionSpec': ...
    class ProtocolParty:
        def name(self) -> java.lang.String: ...
    class ProvingParty(org.ergoplatform.dsl.ContractSpec.ProtocolParty):
        def prove(self, inBox: 'ContractSpec.InputBox', extensions: scala.collection.immutable.Map[typing.Any, special.sigma.AnyValue]) -> scala.util.Try[sigmastate.interpreter.CostedProverResult]: ...
        def prove$default$2(self) -> scala.collection.immutable.Map[typing.Any, special.sigma.AnyValue]: ...
        def pubKey(self) -> special.sigma.SigmaProp: ...
    class ProvingParty$:
        def __init__(self, $outer: 'ContractSpec'): ...
        def apply(self, name: typing.Union[java.lang.String, str]) -> 'ContractSpec.ProvingParty': ...
    class TransactionCandidate:
        def block(self) -> 'ContractSpec.BlockCandidate': ...
        def dataInputs(self) -> scala.collection.Seq['ContractSpec.InputBox']: ...
        def inBox(self, utxoBox: 'ContractSpec.OutBox') -> 'ContractSpec.InputBox': ...
        def inputs(self) -> scala.collection.Seq['ContractSpec.InputBox']: ...
        def outBox(self, value: int, propSpec: 'ContractSpec.PropositionSpec') -> 'ContractSpec.OutBox': ...
        def outputs(self) -> scala.collection.Seq['ContractSpec.OutBox']: ...
        def spending(self, utxos: scala.collection.Seq['ContractSpec.OutBox']) -> 'ContractSpec.TransactionCandidate': ...
        def withDataInputs(self, dataBoxes: scala.collection.Seq['ContractSpec.OutBox']) -> 'ContractSpec.TransactionCandidate': ...
    class VerifyingParty(org.ergoplatform.dsl.ContractSpec.ProtocolParty):
        def verify(self, inBox: 'ContractSpec.InputBox', proverResult: sigmastate.interpreter.ProverResult) -> bool: ...
    class VerifyingParty$:
        def __init__(self, $outer: 'ContractSpec'): ...
        def apply(self, name: typing.Union[java.lang.String, str]) -> 'ContractSpec.VerifyingParty': ...

class ErgoContractSpec(ContractSpec):
    def __init__(self, IR: sigmastate.eval.IRContext): ...
    _Coll__T = typing.TypeVar('_Coll__T')  # <T>
    def Coll(self, items: typing.Any, cT: scalan.RType[_Coll__T]) -> special.collection.Coll[_Coll__T]: ...
    def Colls(self) -> special.collection.CollBuilder: ...
    def IR(self) -> sigmastate.eval.IRContext: ...
    def MinErgValue(self) -> int: ...
    def PropositionSpec(self) -> ContractSpec.PropositionSpec.: ...
    def ProvingParty(self) -> ContractSpec.ProvingParty.: ...
    def VerifyingParty(self) -> ContractSpec.VerifyingParty.: ...
    def dsl(self) -> special.sigma.SigmaDslBuilder: ...
    def error(self, msg: typing.Union[java.lang.String, str]) -> scala.runtime.Nothing.: ...
    def getBlock(self, height: int) -> ContractSpec.ChainBlock: ...
    def getBoxById(self, id: special.collection.Coll[typing.Any]) -> ContractSpec.OutBox: ...
    def getBoxesByParty(self, party: ContractSpec.ProtocolParty) -> scala.collection.Seq[ContractSpec.OutBox]: ...
    def mkPropositionSpec(self, name: typing.Union[java.lang.String, str], dslSpec: scala.Function1[special.sigma.Context, special.sigma.SigmaProp], scriptSpec: ContractSyntax.ErgoScript) -> scala.runtime.Nothing.: ...
    def mkProvingParty(self, name: typing.Union[java.lang.String, str]) -> ContractSpec.ProvingParty: ...
    def mkVerifyingParty(self, name: typing.Union[java.lang.String, str]) -> ContractSpec.VerifyingParty: ...
    def newTransactionContext(self) -> 'ErgoContractSpec.TransactionContext': ...
    def org$ergoplatform$dsl$ContractSpec$_setter_$Colls_$eq(self, x$1: special.collection.CollBuilder) -> None: ...
    def org$ergoplatform$dsl$ContractSpec$_setter_$MinErgValue_$eq(self, x$1: int) -> None: ...
    def org$ergoplatform$dsl$ContractSpec$_setter_$dsl_$eq(self, x$1: special.sigma.SigmaDslBuilder) -> None: ...
    class ErgoOutBox(ContractSpec.OutBox, scala.Product, scala.Serializable):
        $outer: 'ErgoContractSpec' = ...
        def __init__(self, $outer: 'ErgoContractSpec', tx: ContractSpec.TransactionCandidate, boxIndex: int, value: int, propSpec: ContractSpec.PropositionSpec): ...
        def boxIndex(self) -> int: ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        def copy(self, tx: ContractSpec.TransactionCandidate, boxIndex: int, value: int, propSpec: ContractSpec.PropositionSpec) -> 'ErgoContractSpec.ErgoOutBox': ...
        def copy$default$1(self) -> ContractSpec.TransactionCandidate: ...
        def copy$default$2(self) -> int: ...
        def copy$default$3(self) -> int: ...
        def copy$default$4(self) -> ContractSpec.PropositionSpec: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def ergoBox(self) -> scala.runtime.Nothing.: ...
        def hashCode(self) -> int: ...
        def id(self) -> typing.List[int]: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> java.lang.String: ...
        def propSpec(self) -> ContractSpec.PropositionSpec: ...
        def toString(self) -> java.lang.String: ...
        def token(self, id: special.collection.Coll[typing.Any]) -> ContractSyntax.Token: ...
        def tx(self) -> ContractSpec.TransactionCandidate: ...
        def value(self) -> int: ...
        def withRegs(self, regs: scala.collection.Seq[scala.Tuple2[org.ergoplatform.ErgoBox.NonMandatoryRegisterId, typing.Any]]) -> ContractSpec.OutBox: ...
        def withTokens(self, tokens: scala.collection.Seq[ContractSyntax.Token]) -> ContractSpec.OutBox: ...
    class ErgoOutBox$(scala.runtime.AbstractFunction4[ContractSpec.TransactionCandidate, typing.Any, typing.Any, ContractSpec.PropositionSpec, 'ErgoContractSpec.ErgoOutBox'], scala.Serializable):
        def __init__(self, $outer: 'ErgoContractSpec'): ...
        def apply(self, tx: ContractSpec.TransactionCandidate, boxIndex: int, value: int, propSpec: ContractSpec.PropositionSpec) -> 'ErgoContractSpec.ErgoOutBox': ...
        def toString(self) -> java.lang.String: ...
        def unapply(self, x$0: 'ErgoContractSpec.ErgoOutBox') -> scala.Option[scala.Tuple4[ContractSpec.TransactionCandidate, typing.Any, typing.Any, ContractSpec.PropositionSpec]]: ...
    class TransactionContext:
        def attachProof(self, proofs: scala.collection.Seq[scala.Tuple2[ContractSpec.InputBox, sigmastate.interpreter.CostedProverResult]]) -> None: ...
        def block(self) -> ContractSpec.BlockCandidate: ...
        def submit(self) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.dsl")``.

    AvlTreeHelpers: typing.Type[AvlTreeHelpers]
    ContractSpec: typing.Type[ContractSpec]
    ContractSyntax: typing.Type[ContractSyntax]
    ErgoContractSpec: typing.Type[ErgoContractSpec]
    SigmaContractSyntax: typing.Type[SigmaContractSyntax]
    StdContracts: typing.Type[StdContracts]



import java.applet
import java.awt
import java.beans
import java.io
import java.lang
import java.math
import java.net
import java.nio
import java.rmi
import java.security
import java.sql
import java.text
import java.time
import java.util
import typing


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java")``.

    applet: java.applet.__module_protocol__
    awt: java.awt.__module_protocol__
    beans: java.beans.__module_protocol__
    io: java.io.__module_protocol__
    lang: java.lang.__module_protocol__
    math: java.math.__module_protocol__
    net: java.net.__module_protocol__
    nio: java.nio.__module_protocol__
    rmi: java.rmi.__module_protocol__
    security: java.security.__module_protocol__
    sql: java.sql.__module_protocol__
    text: java.text.__module_protocol__
    time: java.time.__module_protocol__
    util: java.util.__module_protocol__
